@@ -1,9 +1,11 @@
 #!/usr/bin/env python3
 # encoding: utf-8
 
+from .download import *
 from .file import *
 from .iter import *
 from .property import *
 from .response import *
+from .text import *
 from .urlopen import *
 
